<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Clarice Acervo
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'clarice' ); ?></a>

	<header id="masthead" class="site-header">
		<button id="menu-toggle" class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><img src="<?php echo get_template_directory_uri(); ?>/img/menu.svg" alt="Abrir menu" class="svg"></button>
		<?php dynamic_sidebar( 'header-switcher' ); ?>
		<div class="site-branding">
			<?php
			the_custom_logo();
			if ( is_front_page() && is_home() ) :
				?>
				<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
				<?php
			else :
				?>
				<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
				<?php
			endif;
			$clarice_description = get_bloginfo( 'description', 'display' );
			if ( $clarice_description || is_customize_preview() ) :
				?>
				<p class="site-description"><?php echo $clarice_description; /* WPCS: xss ok. */ ?></p>
			<?php endif; ?>
		</div><!-- .site-branding -->

		<nav id="site-navigation" class="main-navigation">
			<?php
			wp_nav_menu( array(
				'theme_location' => 'menu-1',
				'menu_id'        => 'primary-menu',
				'container'		 => false,
			) );
			?>
			<?php // if(ICL_LANGUAGE_CODE=='en') : ?>
			<?php // elseif(ICL_LANGUAGE_CODE=='pt-br') : ?>
				<?php echo do_shortcode( '[searchandfilter id="9700"]' ); ?>
			<?php // endif; ?>
		</nav><!-- #site-navigation -->
		<a href="https://claricelispector.ims.com.br" id="portal"><img src="<?php echo get_template_directory_uri(); ?>/img/portal.svg" alt="Voltar à narrativa" class="svg"></a>
	</header><!-- #masthead -->

	<div id="content" class="site-content">
