<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Clarice Acervo
 */

if ( ! function_exists( 'clarice_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function clarice_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html__( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html__( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( '%s', 'post date', 'clarice' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'clarice_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function clarice_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( 'por %s', 'post author', 'clarice' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html__( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

	}
endif;


if ( ! function_exists( 'clarice_share_links' ) ) :
// adds share buttons to current page
	function clarice_share_links() {
		$link = get_the_permalink($post->ID);

		?>
		<ul class="share-links">
			<li>Compartilhar:</li>
			<li><a href="http://twitter.com/share?text=<?php echo bloginfo( 'name' ); ?>&url=<?php echo $link; ?>" target="_blank">Twitter</a></li>
			<li><a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo $link; ?>" target="_blank">Facebook</a></li>
		</ul>

<?php 
	}

endif;

if ( ! function_exists( 'clarice_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function clarice_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			clarice_share_links();
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'clarice' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Editar <span class="screen-reader-text">%s</span>', 'clarice' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'clarice_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function clarice_post_thumbnail() {
		if ( post_password_required() || is_attachment()) {
			return;
		}

		if(!has_post_thumbnail()) : ?>
		<div class="post-thumbnail"></div>
		<?php endif;

		if ( is_singular() ) :
			?>

			<div class="post-thumbnail"><?php the_post_thumbnail(); ?></div><!-- .post-thumbnail -->

		<?php else : ?>

		<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1"><?php the_post_thumbnail( 'post-thumbnail', array( 'alt' => the_title_attribute( array( 'echo' => false, ) ), ) ); ?></a>

		<?php
		endif; // End is_singular().
	}
endif;

if ( ! function_exists( 'wp_body_open' ) ) :
	/**
	 * Shim for sites older than 5.2.
	 *
	 * @link https://core.trac.wordpress.org/ticket/12563
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
endif;




if(!function_exists('clarice_related_posts')) :
	// adds related posts to current
	function clarice_related_posts() {
	global $post;
	$exclude = $post->ID;
	$args = array(
		'post_type' => get_post_type(),
		'posts_per_page' => '6',
		'orderby' => 'rand',
		'post__not_in' => array("$exclude"),
		'suppress_filters' => false
	);
	$relatedQuery = new WP_Query($args);
	if($relatedQuery->have_posts()) : ?>

		<div class="related-posts">

		<hr>

		<h3><?php echo esc_html__('Ver também', 'clarice'); ?></h3>

		<?php
			while($relatedQuery->have_posts()) :
			$relatedQuery->the_post();
			$class = "related";
			?>
			
			<?php include( locate_template( 'components/card-'.get_post_type().'.php', false, false ) ); ?>

		<?php endwhile;
		wp_reset_postdata();
		?>



		</div>

	<?php endif;
	}

endif;