<?php
/**
 * Template part for displaying posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Clarice Acervo
 */

?>

<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
	<header class="entry-header">
		<ul class="meta-single">
			<?php $categories = get_the_category();
				echo '<li>' . esc_html__( $categories[0]->name ) . '</li>';?>
			<li><?php echo get_field('ano'); ?></li>
		</ul>
		<?php
		if ( is_singular() ) :
			the_title( '<h1 class="entry-title">', '</h1>' );
		else :
			the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h2>' );
		endif;

		if ( 'post' === get_post_type() ) :
			?>
			<div class="entry-meta">
				<?php
				clarice_posted_by();
				?>
			</div><!-- .entry-meta -->
		<?php endif; ?>
	</header><!-- .entry-header -->

	<?php clarice_post_thumbnail(); ?>

	<div class="entry-content">
		<?php
		the_content( sprintf(
			wp_kses(
				/* translators: %s: Name of current post. Only visible to screen readers */
				__( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'clarice' ),
				array(
					'span' => array(
						'class' => array(),
					),
				)
			),
			get_the_title()
		) );

		echo '<p class="autoria">'.esc_html__('Por ', 'clarice').get_field('autor').'</p>';

		wp_link_pages( array(
			'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'clarice' ),
			'after'  => '</div>',
		) );
		?>
	</div><!-- .entry-content -->

	<footer class="entry-footer">
		<?php clarice_entry_footer(); ?>
	</footer><!-- .entry-footer -->
	<?php 

	/*
	*  Query posts for a relationship value.
	*  This method uses the meta_query LIKE to match the string "123" to the database value a:1:{i:0;s:3:"123";} (serialized array)
	*/

	$relacionados = get_posts(array(
		'post_type' => array('livro', 'post', 'acervo'),
		'posts_per_page' => -1,
		'meta_query' => array(
			array(
				'key' => 'relacionados', // name of custom field
				'value' => '"' . get_the_ID() . '"', // matches exactly "123", not just 123. This prevents a match for "1234"
				'compare' => 'LIKE'
			)
		)
	));

	$documentos = get_posts(array(
		'post_type' => 'sobre',
		'posts_per_page' => -1,
		'meta_query' => array(
			array(
				'key' => 'relacionados', // name of custom field
				'value' => '"' . get_the_ID() . '"', // matches exactly "123", not just 123. This prevents a match for "1234"
				'compare' => 'LIKE'
			)
		)
	));

	?>
	<?php if($relacioandos || $documentos) : ?>
		<h3 class="titulo-relacionados"><?php echo esc_html__('Ver também', 'clarice'); ?></h3>
	<?php endif; ?>
	<?php if( $relacionados ): ?>
		<div class="related-posts">
		<?php foreach( $relacionados as $relacionado ): ?>
			<?php
			$class = "related";
			$post = $relacionado;
			include( locate_template( 'components/card-'.$post->post_type.'.php', false, false ) );
			global $post;
			?>
		<?php endforeach; ?>
		</div>
	<?php endif; ?>

	<?php if( $documentos ): ?>
		<div class="related-posts sobre">
		<?php foreach( $documentos as $documento ): ?>
			<?php
			$class = "related";
			$post = $documento;

			$tipos = get_the_terms($post->ID, 'tipo');
			$categories = get_the_terms($post->ID, 'formato');
			// $class .= $tipos[0]->slug;
			$chamada = get_the_excerpt($post->ID);
			$author = get_field('author', $post->ID);
			$infos = get_field('outras-informacoes', $post->ID, false);
			$link = get_field('link', $post->ID);
			$video = get_field('video', $post->ID);
			?>
			<!-- include( locate_template( 'components/card-'.$post->post_type.'.php', false, false ) ); -->
			<div <?php post_class(array("card", $class)); ?>>
				<?php $author = esc_html__( 'de ', 'clarice' ). get_field('author', $post->ID);?>
					<?php echo clarice_post_thumbnail(); ?>
					<ul class="meta-sobre">
						<li class="post-type"><span><?php echo esc_html__($tipos[0]->name); ?></span></li>
						<?php echo '<li class="categoria">' . esc_html__( $categories[0]->name ) . '</li>';?>
					</ul>
					<h3 class="titulo">
						<?php if(get_the_content()) : ?>
							<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
						<?php endif; ?>
							<?php if($link) : ?>
								<a href="<?php echo $link; ?>" target="_blank">
							<?php endif; ?>
								<?php the_title(); ?>
							<?php if($link) : ?>
								<svg class="link-externo" xmlns="http://www.w3.org/2000/svg" width="12" height="12">
									<path fill="#fff" stroke="#2b2b2b" d="M1.5 4.518h5.982V10.5H1.5z" class="fundo"/>
									<path fill="#2b2b2b" d="M5.765 1H11v5.39L9.427 7.937l-1.31-1.31L5.393 9.35l-2.69-2.688 2.81-2.808L4.2 2.544z" class="seta"/>
									<path fill="#fff" d="M9.995 2.004l.022 4.885L8.2 5.07 5.32 7.95 4.09 6.723l2.882-2.88-1.85-1.852z"/>
								</svg>
								</a>
							<?php endif; ?>
						<?php if(get_the_content()) : ?>
							</a>
						<?php endif; ?>
					</h3>
					<span class="author"><?php echo $author; ?></span>
					<?php if($chamada) : ?>
						<p class="chamada"><?php echo $chamada; ?></p>
					<?php endif; ?>
				<hr>
			</div>
			<?php global $post;
			?>
		<?php endforeach; ?>
		</div>
	<?php endif; ?>

</article><!-- #post-<?php the_ID(); ?> -->
